/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-07-17 17:32:00.
 * *************************************************
 */

package cn.com.qmth.examcloud.app.utils;

import cn.com.qmth.examcloud.app.model.Constants;
import cn.com.qmth.examcloud.app.model.ResBody;
import cn.com.qmth.examcloud.app.model.Result;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static cn.com.qmth.examcloud.app.model.Constants.PARAM_KEY;
import static cn.com.qmth.examcloud.app.model.Constants.PARAM_TOKEN;

public class HttpUtils {
    private static Logger log = LoggerFactory.getLogger(HttpUtils.class);

    public static Result<String> doGet(String requestUrl, String key, String token) throws Exception {
        //封装请求参数
        Request request = new Request.Builder()
                .url(requestUrl)
                .get()
                .addHeader(PARAM_KEY, key)
                .addHeader(PARAM_TOKEN, token)
                .build();
        //执行请求
        log.debug("[GET] " + requestUrl);
        return call(request);
    }

    public static Result<String> doPost(String requestUrl, RequestBody formBody, String key, String token) throws Exception {
        //封装请求参数
        Request request = new Request.Builder()
                .url(requestUrl)
                .post(formBody)
                .addHeader(PARAM_KEY, key)
                .addHeader(PARAM_TOKEN, token)
                .build();
        //执行请求
        log.debug("[POST] " + requestUrl);
        return call(request);
    }

    public static Result<String> doPut(String requestUrl, RequestBody formBody, String key, String token) throws Exception {
        //封装请求参数
        Request request = new Request.Builder()
                .url(requestUrl)
                .put(formBody)
                .addHeader(PARAM_KEY, key)
                .addHeader(PARAM_TOKEN, token)
                .build();
        //执行请求
        log.debug("[PUT] " + requestUrl);
        return call(request);
    }

    public static Result<String> call(Request request) throws Exception {
        Response response = HttpBuilder.client.getInstance().newCall(request).execute();
        String bodyStr = response.body().string();
        if (response.isSuccessful()) {
            return new Result().success(bodyStr);
        } else {
            log.warn("[Response] " + bodyStr);
            ResBody body = new JsonMapper().fromJson(bodyStr, ResBody.class);
            if (body != null && body.getCode() != null) {
                if (Constants.CODE_403.equals(body.getCode())) {
                    return new Result().noAuthError();
                }
                if (Constants.CODE_404.equals(body.getCode())) {
                    return new Result().noFoundError();
                }
                if (Constants.CODE_0.equals(body.getCode())) {
                    return new Result().error(body.getErrorMsg());
                }
                return new Result().error(body.getDesc());
            }
            return new Result().error(bodyStr);
        }
    }

}